skinfer package
===============

Submodules
----------

skinfer.draft4_generator module
-------------------------------

.. automodule:: skinfer.draft4_generator
    :members:
    :undoc-members:
    :show-inheritance:

skinfer.json_schema_merger module
---------------------------------

.. automodule:: skinfer.json_schema_merger
    :members:
    :undoc-members:
    :show-inheritance:

skinfer.schema_inferer module
-----------------------------

.. automodule:: skinfer.schema_inferer
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: skinfer
    :members:
    :undoc-members:
    :show-inheritance:
